/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.data;

import com.portlandwebworks.commons.domain.EntityBase;
import com.portlandwebworks.commons.domain.IEntity;
import com.portlandwebworks.commons.domain.LookupValueBase;
import org.apache.commons.lang.ArrayUtils;

import java.io.Serializable;
import java.util.*;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class EntityUtils
{
	public static <T extends IEntity> T findById(List<T> source, Serializable id)
	{
		for (T entity : source) {
			if (entity.getId().equals(id)) {
				return entity;
			}
		}
		return null;
	}

	public static <T extends IEntity> Map<Serializable, T> findAllByIds(List<T> source, Collection<? extends Serializable> ids)
	{
		return findAllByIds(source, (Serializable[])new ArrayList(ids).toArray(new Serializable[ids.size()]));
	}
	
	public static <T extends IEntity> Map<Serializable, T> findAllByIds(List<T> source, Serializable[] ids)
	{
		HashMap<Serializable, T> all = new HashMap<Serializable,T>();
		for (T entity : source) {
			if (ArrayUtils.contains(ids, entity.getId())) {
				all.put(entity.getId(), entity);
			}
		}
		return all;
	}

	public static <T extends IEntity> Map<Serializable, T> findComplementByIds(List<T> source, Serializable[] ids)
	{
		HashMap<Serializable, T> complement = new HashMap<Serializable,T>();
		for (T entity : source) {
			if (!ArrayUtils.contains(ids, entity.getId())) {
				complement.put(entity.getId(), entity);
			}
		}
		return complement;
	}

	/**
	 * Returns an array containing the unique identifiers for all entities in the collection provided.
	 *
	 * @param entities
	 * @return          An
	 */
	public static Long[] getEntityIds(Collection<? extends EntityBase> entities)
	{
		if (entities == null || entities.size() == 0) {
			return new Long[0];
		}
		
		Long[] entityIds = new Long[entities.size()];
		int index = 0;
		for (EntityBase entity : entities) {
			entityIds[index++] = entity.getId();
		}
		return entityIds;
	}

	public static Integer[] getLookupValueIds(Collection<? extends LookupValueBase> lookupValues)
	{
		if (lookupValues == null || lookupValues.size() == 0) {
			return new Integer[0];
		}

		Integer[] lookupIds = new Integer[lookupValues.size()];
		int index = 0;
		for (LookupValueBase lookups : lookupValues) {
			lookupIds[index++] = lookups.getId();
		}
		return lookupIds;
	}
}
