/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.domain;

import javax.persistence.MappedSuperclass;
import java.io.Serializable;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
@MappedSuperclass
public abstract class ViewBase
{
	public abstract Serializable getId();

	/**
	 * Two views are equal if:
	 * <ul>
	 * 	<li>They are instances of the same class</li>
	 * 	<li>They both have non-null identifiers</li>
	 * 	<li>Their identifiers are of equal value</li>
	 * </ul>
	 *
	 * @param o	The other view.
	 * @return
	 */
	@Override
	public boolean equals(Object o)
	{
		if (this == o) return true;
		if (o == null || getClass() != o.getClass()) return false;

		ViewBase that = (ViewBase)o;

		if (getId() != null ? !getId().equals(that.getId()) : that.getId() != null) return false;

		return true;
	}

	/**
	 * This view's hashcode is generated from its unique identifier.
	 *
	 * @return
	 */
	@Override
	public int hashCode()
	{
		return getId() != null ? getId().hashCode() : 0;
	}

}
