/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.hibernate;

import org.hibernate.MappingException;
import org.hibernate.dialect.Oracle10gDialect;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class CustomOracle10gDialect extends Oracle10gDialect implements IDialectExtension
{
	public Class getNativeIdentifierGeneratorClass() {

		// The native ID generator for Oracle 10g dialect is normally a sequence generator.  However, this dialect
		// will return a subclass of sequence generator that guesses at the name of the sequence based on the name
		// of the table for which it was created.
		return TableNameSequenceGenerator.class;
	}

	public String getReseedIdentityColumnSQL(String tableName, String columnName, int seedValue)
	{
		throw new MappingException("Dialect does not support identity columns");
	}

	public String getReseedSequenceGeneratorSQL(String tableName, int seedValue)
	{
		String sequenceName = TableNameSequenceGenerator.deriveSequenceName(tableName);

		return "alter sequence " + sequenceName + " minvalue " + seedValue;
	}
}
