/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.reflection;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class FieldUtils
{
	private static HashMap<Class<?>, Field[]> cache = new HashMap<Class<?>, Field[]>();

	/**
	 * Retrieves all declared fields from a class and all of its super classes.
	 * 
	 * @param clazz
	 * @return
	 */
	public static Field[] getDeclaredFields(Class<?> clazz)
	{
		Field[] fieldArray = cache.get(clazz);
		if (fieldArray == null) {
			List<Field> fields = new ArrayList<Field>();
			gatherDeclaredFields(clazz, fields);
			fieldArray = fields.toArray(new Field[fields.size()]);
			cache.put(clazz, fieldArray);
		}
		return fieldArray;
	}

	private static void gatherDeclaredFields(Class<?> clazz, List<Field> fields)
	{
		for (Field field : clazz.getDeclaredFields()) {
			field.setAccessible(true);
			fields.add(field);
		}

		Class<?> superClass = clazz.getSuperclass();
		if (superClass != null) {
			gatherDeclaredFields(superClass, fields);
		}
	}

	public static Field getDeclaredField(Class<?> clazz, String name) {
		try {
			Field field = clazz.getDeclaredField(name);
			field.setAccessible(true);
			return field;
		}
		catch (NoSuchFieldException e) {
			Class<?> superClass = clazz.getSuperclass();
			if (superClass != null) {
				return getDeclaredField(superClass, name);
			}
			return null;
		}
	}

}
